/*
 * Copyright 2013-2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package com.amazonaws.services.stepfunctions.model;

import java.io.Serializable;
import javax.annotation.Generated;

import com.amazonaws.AmazonWebServiceRequest;

/**
 * 
 * @see <a href="http://docs.aws.amazon.com/goto/WebAPI/states-2016-11-23/StartExecution" target="_top">AWS API
 *      Documentation</a>
 */
@Generated("com.amazonaws:aws-java-sdk-code-generator")
public class StartExecutionRequest extends com.amazonaws.AmazonWebServiceRequest implements Serializable, Cloneable {

    /**
     * <p>
     * The Amazon Resource Name (ARN) of the state machine to execute.
     * </p>
     */
    private String stateMachineArn;
    /**
     * <p>
     * The name of the execution. This name must be unique for your AWS account and region for 90 days. For more
     * information, see <a
     * href="http://docs.aws.amazon.com/step-functions/latest/dg/limits.html#service-limits-state-machine-executions">
     * Limits Related to State Machine Executions</a> in the <i>AWS Step Functions Developer Guide</i>.
     * </p>
     * <important>
     * <p>
     * An execution can't use the name of another execution for 90 days.
     * </p>
     * <p>
     * When you make multiple <code>StartExecution</code> calls with the same name, the new execution doesn't run and
     * the following rules apply:
     * </p>
     * <ul>
     * <li>
     * <p>
     * When the original execution is open and the execution input from the new call is <i>different</i>, the
     * <code>ExecutionAlreadyExists</code> message is returned.
     * </p>
     * </li>
     * <li>
     * <p>
     * When the original execution is open and the execution input from the new call is <i>identical</i>, the
     * <code>Success</code> message is returned.
     * </p>
     * </li>
     * <li>
     * <p>
     * When the original execution is closed, the <code>ExecutionAlreadyExists</code> message is returned regardless of
     * input.
     * </p>
     * </li>
     * </ul>
     * </important>
     * <p>
     * A name must <i>not</i> contain:
     * </p>
     * <ul>
     * <li>
     * <p>
     * whitespace
     * </p>
     * </li>
     * <li>
     * <p>
     * brackets <code>&lt; &gt; { } [ ]</code>
     * </p>
     * </li>
     * <li>
     * <p>
     * wildcard characters <code>? *</code>
     * </p>
     * </li>
     * <li>
     * <p>
     * special characters <code>" # % \ ^ | ~ ` $ &amp; , ; : /</code>
     * </p>
     * </li>
     * <li>
     * <p>
     * control characters (<code>U+0000-001F</code>, <code>U+007F-009F</code>)
     * </p>
     * </li>
     * </ul>
     */
    private String name;
    /**
     * <p>
     * The string that contains the JSON input data for the execution, for example:
     * </p>
     * <p>
     * <code>"input": "{\"first_name\" : \"test\"}"</code>
     * </p>
     * <note>
     * <p>
     * If you don't include any JSON input data, you still must include the two braces, for example:
     * <code>"input": "{}"</code>
     * </p>
     * </note>
     */
    private String input;

    /**
     * <p>
     * The Amazon Resource Name (ARN) of the state machine to execute.
     * </p>
     * 
     * @param stateMachineArn
     *        The Amazon Resource Name (ARN) of the state machine to execute.
     */

    public void setStateMachineArn(String stateMachineArn) {
        this.stateMachineArn = stateMachineArn;
    }

    /**
     * <p>
     * The Amazon Resource Name (ARN) of the state machine to execute.
     * </p>
     * 
     * @return The Amazon Resource Name (ARN) of the state machine to execute.
     */

    public String getStateMachineArn() {
        return this.stateMachineArn;
    }

    /**
     * <p>
     * The Amazon Resource Name (ARN) of the state machine to execute.
     * </p>
     * 
     * @param stateMachineArn
     *        The Amazon Resource Name (ARN) of the state machine to execute.
     * @return Returns a reference to this object so that method calls can be chained together.
     */

    public StartExecutionRequest withStateMachineArn(String stateMachineArn) {
        setStateMachineArn(stateMachineArn);
        return this;
    }

    /**
     * <p>
     * The name of the execution. This name must be unique for your AWS account and region for 90 days. For more
     * information, see <a
     * href="http://docs.aws.amazon.com/step-functions/latest/dg/limits.html#service-limits-state-machine-executions">
     * Limits Related to State Machine Executions</a> in the <i>AWS Step Functions Developer Guide</i>.
     * </p>
     * <important>
     * <p>
     * An execution can't use the name of another execution for 90 days.
     * </p>
     * <p>
     * When you make multiple <code>StartExecution</code> calls with the same name, the new execution doesn't run and
     * the following rules apply:
     * </p>
     * <ul>
     * <li>
     * <p>
     * When the original execution is open and the execution input from the new call is <i>different</i>, the
     * <code>ExecutionAlreadyExists</code> message is returned.
     * </p>
     * </li>
     * <li>
     * <p>
     * When the original execution is open and the execution input from the new call is <i>identical</i>, the
     * <code>Success</code> message is returned.
     * </p>
     * </li>
     * <li>
     * <p>
     * When the original execution is closed, the <code>ExecutionAlreadyExists</code> message is returned regardless of
     * input.
     * </p>
     * </li>
     * </ul>
     * </important>
     * <p>
     * A name must <i>not</i> contain:
     * </p>
     * <ul>
     * <li>
     * <p>
     * whitespace
     * </p>
     * </li>
     * <li>
     * <p>
     * brackets <code>&lt; &gt; { } [ ]</code>
     * </p>
     * </li>
     * <li>
     * <p>
     * wildcard characters <code>? *</code>
     * </p>
     * </li>
     * <li>
     * <p>
     * special characters <code>" # % \ ^ | ~ ` $ &amp; , ; : /</code>
     * </p>
     * </li>
     * <li>
     * <p>
     * control characters (<code>U+0000-001F</code>, <code>U+007F-009F</code>)
     * </p>
     * </li>
     * </ul>
     * 
     * @param name
     *        The name of the execution. This name must be unique for your AWS account and region for 90 days. For more
     *        information, see <a href=
     *        "http://docs.aws.amazon.com/step-functions/latest/dg/limits.html#service-limits-state-machine-executions">
     *        Limits Related to State Machine Executions</a> in the <i>AWS Step Functions Developer Guide</i>.</p>
     *        <important>
     *        <p>
     *        An execution can't use the name of another execution for 90 days.
     *        </p>
     *        <p>
     *        When you make multiple <code>StartExecution</code> calls with the same name, the new execution doesn't run
     *        and the following rules apply:
     *        </p>
     *        <ul>
     *        <li>
     *        <p>
     *        When the original execution is open and the execution input from the new call is <i>different</i>, the
     *        <code>ExecutionAlreadyExists</code> message is returned.
     *        </p>
     *        </li>
     *        <li>
     *        <p>
     *        When the original execution is open and the execution input from the new call is <i>identical</i>, the
     *        <code>Success</code> message is returned.
     *        </p>
     *        </li>
     *        <li>
     *        <p>
     *        When the original execution is closed, the <code>ExecutionAlreadyExists</code> message is returned
     *        regardless of input.
     *        </p>
     *        </li>
     *        </ul>
     *        </important>
     *        <p>
     *        A name must <i>not</i> contain:
     *        </p>
     *        <ul>
     *        <li>
     *        <p>
     *        whitespace
     *        </p>
     *        </li>
     *        <li>
     *        <p>
     *        brackets <code>&lt; &gt; { } [ ]</code>
     *        </p>
     *        </li>
     *        <li>
     *        <p>
     *        wildcard characters <code>? *</code>
     *        </p>
     *        </li>
     *        <li>
     *        <p>
     *        special characters <code>" # % \ ^ | ~ ` $ &amp; , ; : /</code>
     *        </p>
     *        </li>
     *        <li>
     *        <p>
     *        control characters (<code>U+0000-001F</code>, <code>U+007F-009F</code>)
     *        </p>
     *        </li>
     */

    public void setName(String name) {
        this.name = name;
    }

    /**
     * <p>
     * The name of the execution. This name must be unique for your AWS account and region for 90 days. For more
     * information, see <a
     * href="http://docs.aws.amazon.com/step-functions/latest/dg/limits.html#service-limits-state-machine-executions">
     * Limits Related to State Machine Executions</a> in the <i>AWS Step Functions Developer Guide</i>.
     * </p>
     * <important>
     * <p>
     * An execution can't use the name of another execution for 90 days.
     * </p>
     * <p>
     * When you make multiple <code>StartExecution</code> calls with the same name, the new execution doesn't run and
     * the following rules apply:
     * </p>
     * <ul>
     * <li>
     * <p>
     * When the original execution is open and the execution input from the new call is <i>different</i>, the
     * <code>ExecutionAlreadyExists</code> message is returned.
     * </p>
     * </li>
     * <li>
     * <p>
     * When the original execution is open and the execution input from the new call is <i>identical</i>, the
     * <code>Success</code> message is returned.
     * </p>
     * </li>
     * <li>
     * <p>
     * When the original execution is closed, the <code>ExecutionAlreadyExists</code> message is returned regardless of
     * input.
     * </p>
     * </li>
     * </ul>
     * </important>
     * <p>
     * A name must <i>not</i> contain:
     * </p>
     * <ul>
     * <li>
     * <p>
     * whitespace
     * </p>
     * </li>
     * <li>
     * <p>
     * brackets <code>&lt; &gt; { } [ ]</code>
     * </p>
     * </li>
     * <li>
     * <p>
     * wildcard characters <code>? *</code>
     * </p>
     * </li>
     * <li>
     * <p>
     * special characters <code>" # % \ ^ | ~ ` $ &amp; , ; : /</code>
     * </p>
     * </li>
     * <li>
     * <p>
     * control characters (<code>U+0000-001F</code>, <code>U+007F-009F</code>)
     * </p>
     * </li>
     * </ul>
     * 
     * @return The name of the execution. This name must be unique for your AWS account and region for 90 days. For more
     *         information, see <a href=
     *         "http://docs.aws.amazon.com/step-functions/latest/dg/limits.html#service-limits-state-machine-executions"
     *         > Limits Related to State Machine Executions</a> in the <i>AWS Step Functions Developer Guide</i>.</p>
     *         <important>
     *         <p>
     *         An execution can't use the name of another execution for 90 days.
     *         </p>
     *         <p>
     *         When you make multiple <code>StartExecution</code> calls with the same name, the new execution doesn't
     *         run and the following rules apply:
     *         </p>
     *         <ul>
     *         <li>
     *         <p>
     *         When the original execution is open and the execution input from the new call is <i>different</i>, the
     *         <code>ExecutionAlreadyExists</code> message is returned.
     *         </p>
     *         </li>
     *         <li>
     *         <p>
     *         When the original execution is open and the execution input from the new call is <i>identical</i>, the
     *         <code>Success</code> message is returned.
     *         </p>
     *         </li>
     *         <li>
     *         <p>
     *         When the original execution is closed, the <code>ExecutionAlreadyExists</code> message is returned
     *         regardless of input.
     *         </p>
     *         </li>
     *         </ul>
     *         </important>
     *         <p>
     *         A name must <i>not</i> contain:
     *         </p>
     *         <ul>
     *         <li>
     *         <p>
     *         whitespace
     *         </p>
     *         </li>
     *         <li>
     *         <p>
     *         brackets <code>&lt; &gt; { } [ ]</code>
     *         </p>
     *         </li>
     *         <li>
     *         <p>
     *         wildcard characters <code>? *</code>
     *         </p>
     *         </li>
     *         <li>
     *         <p>
     *         special characters <code>" # % \ ^ | ~ ` $ &amp; , ; : /</code>
     *         </p>
     *         </li>
     *         <li>
     *         <p>
     *         control characters (<code>U+0000-001F</code>, <code>U+007F-009F</code>)
     *         </p>
     *         </li>
     */

    public String getName() {
        return this.name;
    }

    /**
     * <p>
     * The name of the execution. This name must be unique for your AWS account and region for 90 days. For more
     * information, see <a
     * href="http://docs.aws.amazon.com/step-functions/latest/dg/limits.html#service-limits-state-machine-executions">
     * Limits Related to State Machine Executions</a> in the <i>AWS Step Functions Developer Guide</i>.
     * </p>
     * <important>
     * <p>
     * An execution can't use the name of another execution for 90 days.
     * </p>
     * <p>
     * When you make multiple <code>StartExecution</code> calls with the same name, the new execution doesn't run and
     * the following rules apply:
     * </p>
     * <ul>
     * <li>
     * <p>
     * When the original execution is open and the execution input from the new call is <i>different</i>, the
     * <code>ExecutionAlreadyExists</code> message is returned.
     * </p>
     * </li>
     * <li>
     * <p>
     * When the original execution is open and the execution input from the new call is <i>identical</i>, the
     * <code>Success</code> message is returned.
     * </p>
     * </li>
     * <li>
     * <p>
     * When the original execution is closed, the <code>ExecutionAlreadyExists</code> message is returned regardless of
     * input.
     * </p>
     * </li>
     * </ul>
     * </important>
     * <p>
     * A name must <i>not</i> contain:
     * </p>
     * <ul>
     * <li>
     * <p>
     * whitespace
     * </p>
     * </li>
     * <li>
     * <p>
     * brackets <code>&lt; &gt; { } [ ]</code>
     * </p>
     * </li>
     * <li>
     * <p>
     * wildcard characters <code>? *</code>
     * </p>
     * </li>
     * <li>
     * <p>
     * special characters <code>" # % \ ^ | ~ ` $ &amp; , ; : /</code>
     * </p>
     * </li>
     * <li>
     * <p>
     * control characters (<code>U+0000-001F</code>, <code>U+007F-009F</code>)
     * </p>
     * </li>
     * </ul>
     * 
     * @param name
     *        The name of the execution. This name must be unique for your AWS account and region for 90 days. For more
     *        information, see <a href=
     *        "http://docs.aws.amazon.com/step-functions/latest/dg/limits.html#service-limits-state-machine-executions">
     *        Limits Related to State Machine Executions</a> in the <i>AWS Step Functions Developer Guide</i>.</p>
     *        <important>
     *        <p>
     *        An execution can't use the name of another execution for 90 days.
     *        </p>
     *        <p>
     *        When you make multiple <code>StartExecution</code> calls with the same name, the new execution doesn't run
     *        and the following rules apply:
     *        </p>
     *        <ul>
     *        <li>
     *        <p>
     *        When the original execution is open and the execution input from the new call is <i>different</i>, the
     *        <code>ExecutionAlreadyExists</code> message is returned.
     *        </p>
     *        </li>
     *        <li>
     *        <p>
     *        When the original execution is open and the execution input from the new call is <i>identical</i>, the
     *        <code>Success</code> message is returned.
     *        </p>
     *        </li>
     *        <li>
     *        <p>
     *        When the original execution is closed, the <code>ExecutionAlreadyExists</code> message is returned
     *        regardless of input.
     *        </p>
     *        </li>
     *        </ul>
     *        </important>
     *        <p>
     *        A name must <i>not</i> contain:
     *        </p>
     *        <ul>
     *        <li>
     *        <p>
     *        whitespace
     *        </p>
     *        </li>
     *        <li>
     *        <p>
     *        brackets <code>&lt; &gt; { } [ ]</code>
     *        </p>
     *        </li>
     *        <li>
     *        <p>
     *        wildcard characters <code>? *</code>
     *        </p>
     *        </li>
     *        <li>
     *        <p>
     *        special characters <code>" # % \ ^ | ~ ` $ &amp; , ; : /</code>
     *        </p>
     *        </li>
     *        <li>
     *        <p>
     *        control characters (<code>U+0000-001F</code>, <code>U+007F-009F</code>)
     *        </p>
     *        </li>
     * @return Returns a reference to this object so that method calls can be chained together.
     */

    public StartExecutionRequest withName(String name) {
        setName(name);
        return this;
    }

    /**
     * <p>
     * The string that contains the JSON input data for the execution, for example:
     * </p>
     * <p>
     * <code>"input": "{\"first_name\" : \"test\"}"</code>
     * </p>
     * <note>
     * <p>
     * If you don't include any JSON input data, you still must include the two braces, for example:
     * <code>"input": "{}"</code>
     * </p>
     * </note>
     * 
     * @param input
     *        The string that contains the JSON input data for the execution, for example:</p>
     *        <p>
     *        <code>"input": "{\"first_name\" : \"test\"}"</code>
     *        </p>
     *        <note>
     *        <p>
     *        If you don't include any JSON input data, you still must include the two braces, for example:
     *        <code>"input": "{}"</code>
     *        </p>
     */

    public void setInput(String input) {
        this.input = input;
    }

    /**
     * <p>
     * The string that contains the JSON input data for the execution, for example:
     * </p>
     * <p>
     * <code>"input": "{\"first_name\" : \"test\"}"</code>
     * </p>
     * <note>
     * <p>
     * If you don't include any JSON input data, you still must include the two braces, for example:
     * <code>"input": "{}"</code>
     * </p>
     * </note>
     * 
     * @return The string that contains the JSON input data for the execution, for example:</p>
     *         <p>
     *         <code>"input": "{\"first_name\" : \"test\"}"</code>
     *         </p>
     *         <note>
     *         <p>
     *         If you don't include any JSON input data, you still must include the two braces, for example:
     *         <code>"input": "{}"</code>
     *         </p>
     */

    public String getInput() {
        return this.input;
    }

    /**
     * <p>
     * The string that contains the JSON input data for the execution, for example:
     * </p>
     * <p>
     * <code>"input": "{\"first_name\" : \"test\"}"</code>
     * </p>
     * <note>
     * <p>
     * If you don't include any JSON input data, you still must include the two braces, for example:
     * <code>"input": "{}"</code>
     * </p>
     * </note>
     * 
     * @param input
     *        The string that contains the JSON input data for the execution, for example:</p>
     *        <p>
     *        <code>"input": "{\"first_name\" : \"test\"}"</code>
     *        </p>
     *        <note>
     *        <p>
     *        If you don't include any JSON input data, you still must include the two braces, for example:
     *        <code>"input": "{}"</code>
     *        </p>
     * @return Returns a reference to this object so that method calls can be chained together.
     */

    public StartExecutionRequest withInput(String input) {
        setInput(input);
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getStateMachineArn() != null)
            sb.append("StateMachineArn: ").append(getStateMachineArn()).append(",");
        if (getName() != null)
            sb.append("Name: ").append(getName()).append(",");
        if (getInput() != null)
            sb.append("Input: ").append(getInput());
        sb.append("}");
        return sb.toString();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;

        if (obj instanceof StartExecutionRequest == false)
            return false;
        StartExecutionRequest other = (StartExecutionRequest) obj;
        if (other.getStateMachineArn() == null ^ this.getStateMachineArn() == null)
            return false;
        if (other.getStateMachineArn() != null && other.getStateMachineArn().equals(this.getStateMachineArn()) == false)
            return false;
        if (other.getName() == null ^ this.getName() == null)
            return false;
        if (other.getName() != null && other.getName().equals(this.getName()) == false)
            return false;
        if (other.getInput() == null ^ this.getInput() == null)
            return false;
        if (other.getInput() != null && other.getInput().equals(this.getInput()) == false)
            return false;
        return true;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;

        hashCode = prime * hashCode + ((getStateMachineArn() == null) ? 0 : getStateMachineArn().hashCode());
        hashCode = prime * hashCode + ((getName() == null) ? 0 : getName().hashCode());
        hashCode = prime * hashCode + ((getInput() == null) ? 0 : getInput().hashCode());
        return hashCode;
    }

    @Override
    public StartExecutionRequest clone() {
        return (StartExecutionRequest) super.clone();
    }

}
